@@ -2549,7 +2549,7 @@ void WriteJSONTrigger(Trigger const *t, int include_tags)
         PrintJSONKeyPairInt("rep", t->rep);
     }
     if (t->d != NO_DAY && t->m != NO_MON && t->y != NO_YR) {
-        printf("\"trigbase\":\"%04d-%02d-%-2d\",",
+        printf("\"trigbase\":\"%04d-%02d-%02d\",",
                t->y, t->m+1, t->d);
     }
     /* Local omit is an array of days from 0=monday to 6=sunday.
