@@ -849,6 +849,15 @@ void InitRemind(int argc, char const *argv[])
         (void) CalcMinsFromUTC(DSEToday, MinutesPastMidnight(0),
                                &MinsFromUTC, NULL);
     }
+
+    /* If stdout is a tty, enable terminal hyperlinks by default */
+    if (TerminalHyperlinks == -1) {
+        if (isatty(STDOUT_FILENO)) {
+            TerminalHyperlinks = 1;
+        } else {
+            TerminalHyperlinks = 0;
+        }
+    }
 }
 
 /***************************************************************/
